﻿Option Strict On

Imports Microsoft.WindowsAPICodePack.Dialogs
Imports Microsoft.WindowsAPICodePack.Shell
Imports Microsoft.WindowsAPICodePack.ApplicationServices

Public Class fMenu

    Private Sub fMenu_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        CapturePowerManagementEvents()
        GetPowerSettings()
    End Sub

#Region " -- Explorer / File Dialog -- "

    Private Sub btnExplorerPlainOld_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnExplorerPlainOld.Click
        'Displays a plain old file open dialog control
        Dim d As New OpenFileDialog
        If d.ShowDialog = Windows.Forms.DialogResult.OK Then
            MessageBox.Show("You have selected : " + d.FileName)
        End If
        d.Dispose()
    End Sub

    Private Sub btnExplorerNewControl_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnExplorerNewControl.Click
        'Displays the same dialog as previous but using the new class
        Dim d As New CommonOpenFileDialog
        If d.ShowDialog = Windows.Forms.DialogResult.OK Then
            MessageBox.Show("You have selected : " + d.FileName)
        End If
        d.Dispose()
    End Sub

    Private Sub btnExplorerNewControlFolderPicker_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnExplorerNewControlFolderPicker.Click
        'transforms the dialog to a folder picker
        Dim d As New CommonOpenFileDialog
        d.IsFolderPicker = True
        If d.ShowDialog = Windows.Forms.DialogResult.OK Then
            MessageBox.Show("You have selected : " + d.FileName)
        End If
        d.Dispose()
    End Sub

    Private Sub btnExplorerNewControlKnownFolders_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnExplorerNewControlKnownFolders.Click
        'check if the OS supports the Shell features
        If ShellLibrary.IsPlatformSupported Then
            'Set the initial directory to one of Windows' know folders
            Dim d As New CommonOpenFileDialog
            d.InitialDirectoryShellContainer = CType(KnownFolders.MusicLibrary, ShellContainer)
            If d.ShowDialog = Windows.Forms.DialogResult.OK Then
                MessageBox.Show("You have selected : " + d.FileName)
            End If
            d.Dispose()
        Else
            MessageBox.Show("this version of Windows does not support this feature!", "Unsupported feature", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End If
    End Sub

    Private Sub btnExplorerNewControlBrowser_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnExplorerNewControlBrowser.Click
        'Displays a custom file explorer
        fExplorerControl.ShowDialog()
    End Sub

#End Region ' -- Explorer / File Dialog --

#Region " -- Task dialog -- "

    Private Sub btnTaskDialogTest_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnTaskDialogTest.Click
        fTaskDialog.Show()
    End Sub

#End Region ' -- Task dialog -- 

#Region " -- Power Management -- "

    ' Get the current property values from PowerManager.
    ' This method is called on startup.
    Private Sub GetPowerSettings()
        PowerEvents(Nothing, Nothing)
    End Sub

    ' Adds event handlers for PowerManager events.
    Private Sub CapturePowerManagementEvents()
        AddHandler PowerManager.PowerSourceChanged, AddressOf PowerEvents
        If PowerManager.IsBatteryPresent Then
            AddHandler PowerManager.BatteryLifePercentChanged, AddressOf PowerEvents
        End If
    End Sub

    Private Sub PowerEvents(ByVal sender As Object, ByVal e As EventArgs)
        lblPowerManagement.Text = PowerManager.PowerSource.ToString()
        If PowerManager.IsBatteryPresent Then
            lblPowerManagement.Text += ", Battery life = " + PowerManager.BatteryLifePercent.ToString + "%"
        End If
    End Sub

    Private Sub btnPowerManagement_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnPowerManagement.Click
        ' If running on battery, don't start the fake task
        If PowerManager.PowerSource <> PowerSource.Battery Then
            MessageBox.Show("Now starting a long, resources intensive ... fake job!", _
                            "Alert", _
                            MessageBoxButtons.OK, _
                            MessageBoxIcon.Exclamation)
        Else
            MessageBox.Show("Cannot do this task while running on batteries!", _
                            "Alert", _
                            MessageBoxButtons.OK, _
                            MessageBoxIcon.Error)
        End If
    End Sub

#End Region ' -- Power Management -- 

End Class
