﻿Option Strict On

'Imports Microsoft.SDK.Samples.VistaBridge.Library.AppRecoveryRestart
Imports Microsoft.WindowsAPICodePack.ApplicationServices
Imports System.IO

Public Class Form1

#Region " - Members - "

    '//to get around "marshaling to form thread" issues, keep
    '//an echo of the text to be recovered in a member variable
    Private _TextboxText As String

    Private ReadOnly _RecoveryPath As String = _
        Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.ApplicationData), _
                     "App Recov.txt")

#End Region ' - Members - 

#Region " - Constructors - "

    Public Sub New()
        ' This call is required by the Windows Form Designer.
        InitializeComponent()

        ' Add any initialization after the InitializeComponent() call.
    End Sub

    Public Sub New(ByVal pRecoveryPath As String)
        Me.New()
        If Not String.IsNullOrEmpty(pRecoveryPath) _
            AndAlso File.Exists(pRecoveryPath) _
        Then
            Me.lblRecoveryPath.Text = pRecoveryPath
            Dim r As StreamReader = File.OpenText(pRecoveryPath)
            textBox1.Text = r.ReadLine()
            _TextboxText = textBox1.Text
            r.Close()
            r.Dispose()
            r = Nothing

            '//should clean away the file - I am leaving it so it can be 
            '//examined while debugging/understanding the process, or so 
            '//restarts can be repeated under the debugger
        End If
    End Sub

#End Region ' - Constructors - 

#Region " - Events - "

    Private Sub Form1_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        'Register the recovery notification
        Dim data As New RecoveryData(New RecoveryCallback(AddressOf SaveForRecover), Nothing)
        Dim recoverySettings = New RecoverySettings(data, 5000)
        ApplicationRestartRecoveryManager.RegisterForApplicationRecovery(recoverySettings)

        'Register the Restart Notification
        Dim restartSettings = New RestartSettings( _
            Convert.ToChar(34) + _RecoveryPath + Convert.ToChar(34), RestartRestrictions.None)
        ApplicationRestartRecoveryManager.RegisterForApplicationRestart(restartSettings)
    End Sub

    Private Sub Hang_Click() Handles Hang.Click
        Do While True
            'nothing to ensure that we loop tight!
        Loop
    End Sub

    Private Sub FatalError_Click() Handles FatalError.Click
        timer1.Enabled = False
        Dim zero As Integer = 0
        Dim i As Integer = Convert.ToInt32(3 / zero)
    End Sub

    Private Sub timer1_Tick(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles timer1.Tick
        Static sStartTime As DateTime
        If sStartTime = DateTime.MinValue Then sStartTime = DateTime.Now

        Me.lblTimer.Text = DateTime.Now.ToString("HH:mm:ss")
        If sStartTime.AddMinutes(1) < DateTime.Now Then
            lblTimer.BackColor = Color.LightGreen
        End If
    End Sub

    Private Sub textBox1_TextChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles textBox1.TextChanged
        _TextboxText = textBox1.Text
    End Sub

#End Region ' - Events - 

#Region " - Methods - "

    Private Function SaveForRecover(ByVal state As Object) As Integer
        Dim w As StreamWriter = File.CreateText(_RecoveryPath)
        w.WriteLine(_TextboxText)
        w.Close()
        '//simulated delay
        For i As Integer = 1 To 10
            Dim b As Boolean = Me.Ping()
            If (b) Then Return 0
            System.Threading.Thread.Sleep(2000)
        Next
        ApplicationRestartRecoveryManager.ApplicationRecoveryFinished(True)
        Return 0
    End Function

    Private Function Ping() As Boolean
        'ApplicationRecoveryInProgress returns TRUE if I hit the Cancel button
        Dim blnEsc As Boolean = ApplicationRestartRecoveryManager.ApplicationRecoveryInProgress()
        If blnEsc Then
            MessageBox.Show("Cancelled")
        End If
        Return blnEsc
    End Function

#End Region ' - Methods - 

End Class
